==> lincvs-1.4.2-0-generic-src.tgz: lincvs-1.4.2/compat/mac-compat.cpp <==
/****************************************************************************
**
** Copyright (C) 1999-2004 Tilo Riemer <riemer@lincvs.org>
**
**
**----------------------------------------------------------------------------
**
**----------------------------------------------------------------------------
**
** LinCVS is available under two different licenses:
**
** If LinCVS is linked against the GPLed version of Qt 
** LinCVS is released under the terms of GPL also.
**
** If LinCVS is linked against a nonGPLed version of Qt 
** LinCVS is released under the terms of the 
** LinCVS License for non-Unix platforms (LLNU)
**
**
** LinCVS License for non-Unix platforms (LLNU):
**
** Redistribution and use in binary form, without modification, 
** are permitted provided that the following conditions are met:
**
** 1. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 2. It is not permitted to distribute the binary package under a name
**    different than LinCVS.
** 3. The name of the authors may not be used to endorse or promote
**    products derived from this software without specific prior written
**    permission.
** 4. The source code is the creative property of the authors.
**    Extensions and development under the terms of the Gnu Public License
**    are limited to the Unix platform. Any distribution or compilation of 
**    the source code against libraries licensed other than gpl requires 
**    the written permission of the authors.
**
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
**
** LinCVS License for Unix platforms:
**
** This program is free software; you can redistribute it and/or modify 
** it under the terms of the GNU General Public License as published by 
** the Free Software Foundation; either version 2 of the License, or 
** (at your  option) any later version.  This program is distributed in 
** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
** PARTICULAR PURPOSE.
**
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software Foundation,
** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**
*****************************************************************************/

#include <qstring.h>

//----------------------------------------------------------------------------

#ifdef Q_WS_MAC

//----------------------------------------------------------------------------

#include "mac-compat.h"

//----------------------------------------------------------------------------

//#include <CoreFoundation/CoreFoundation.h>
//#include <CoreServices/CoreServices.h>

//----------------------------------------------------------------------------

#include <qdir.h>
#include <qapplication.h>

//----------------------------------------------------------------------------

/**
   Returns the full path to the application directory
*/
const QString LF::appDir(const char*) 
{
return qApp->applicationDirPath();

/*
   CFURLRef pluginRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
   CFStringRef macPath = CFURLCopyFileSystemPath(pluginRef, 
                                                 kCFURLPOSIXPathStyle);
   const char *pathPtr = CFStringGetCStringPtr(macPath, 
                                               CFStringGetSystemEncoding());
   //qDebug("Path = %s", pathPtr);

   // HACK: if we now where the right place of resources is we will correct it
   QString appDirString = pathPtr;
   appDirString += "/Contents/MacOS";
   return appDirString;
*/
}

//----------------------------------------------------------------------------

QString LF::validateEchse(const QString arg)
{
   QString valArg = arg;
   
   //look for binary into *.app
   int secondGaensefuesschen = arg.find("\"", 1);
   QString cmd = arg.left(secondGaensefuesschen);
   cmd = cmd.right(cmd.length() - 1);
   QString argRight = arg.right(arg.length() - secondGaensefuesschen - 1);
  
    
   //we should search for an API func which returns path to echse for a bundle
   
   QString cmdApp = cmd;
   if (cmdApp.findRev(".app") != (int)(cmdApp.length() - 4)) cmdApp += ".app";
    
   QDir app(cmdApp);
   
   if (app.exists()) {
      QString appName = cmd.right(cmd.length() - cmd.findRev("/"));
      if (appName.findRev(".app") == (int)(appName.length() - 4)) appName = appName.left(appName.length() - 4);
      qDebug(appName);
      QString cmdBin = cmdApp + "/Contents/MacOS" + appName;
      qDebug(cmdBin);
    
      valArg = "\"" + cmdBin + "\"" + argRight;
   }
   qDebug(valArg);

   return valArg;
}

//----------------------------------------------------------------------------

#endif  //Q_WS_MAC

==> lincvs-1.4.4-0-generic-src.tgz: lincvs-1.4.4/compat/mac-compat.cpp <==
/****************************************************************************
**
** Copyright (C) 1999-2004 Tilo Riemer <riemer@lincvs.org>
**
**
**----------------------------------------------------------------------------
**
**----------------------------------------------------------------------------
**
** LinCVS is available under two different licenses:
**
** If LinCVS is linked against the GPLed version of Qt 
** LinCVS is released under the terms of GPL also.
**
** If LinCVS is linked against a nonGPLed version of Qt 
** LinCVS is released under the terms of the 
** LinCVS License for non-Unix platforms (LLNU)
**
**
** LinCVS License for non-Unix platforms (LLNU):
**
** Redistribution and use in binary form, without modification, 
** are permitted provided that the following conditions are met:
**
** 1. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 2. It is not permitted to distribute the binary package under a name
**    different than LinCVS.
** 3. The name of the authors may not be used to endorse or promote
**    products derived from this software without specific prior written
**    permission.
** 4. The source code is the creative property of the authors.
**    Extensions and development under the terms of the Gnu Public License
**    are limited to the Unix platform. Any distribution or compilation of 
**    the source code against libraries licensed other than gpl requires 
**    the written permission of the authors.
**
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
**
** LinCVS License for Unix platforms:
**
** This program is free software; you can redistribute it and/or modify 
** it under the terms of the GNU General Public License as published by 
** the Free Software Foundation; either version 2 of the License, or 
** (at your  option) any later version.  This program is distributed in 
** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
** PARTICULAR PURPOSE.
**
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software Foundation,
** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**
*****************************************************************************/

#include <qstring.h>

//----------------------------------------------------------------------------

#ifdef Q_WS_MAC

//----------------------------------------------------------------------------

#include "mac-compat.h"

//----------------------------------------------------------------------------

#include <CoreFoundation/CoreFoundation.h>
#include <CoreServices/CoreServices.h>

//----------------------------------------------------------------------------

#include <qdir.h>
#include <qapplication.h>

//----------------------------------------------------------------------------

/**
   Returns the full path to the application directory
*/
const QString LF::appDir(const char*) 
{
   CFURLRef pluginRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
   CFStringRef macPath = CFURLCopyFileSystemPath(pluginRef, 
                                                 kCFURLPOSIXPathStyle);
   const char *pathPtr = CFStringGetCStringPtr(macPath, 
                                               CFStringGetSystemEncoding());
   //qDebug("Path = %s", pathPtr);

   // HACK: if we now where the right place of resources is we will correct it
   QString appDirString = pathPtr;
   appDirString += "/Contents/MacOS";
   return appDirString;
}

//----------------------------------------------------------------------------

QString LF::validateEchse(const QString arg)
{
   QString valArg = arg;
   
   //look for binary into *.app
   int secondGaensefuesschen = arg.find("\"", 1);
   QString cmd = arg.left(secondGaensefuesschen);
   cmd = cmd.right(cmd.length() - 1);
   QString argRight = arg.right(arg.length() - secondGaensefuesschen - 1);
  
    
   //we should search for an API func which returns path to echse for a bundle
   
   QString cmdApp = cmd;
   if (cmdApp.findRev(".app") != (int)(cmdApp.length() - 4)) cmdApp += ".app";
    
   QDir app(cmdApp);
   
   if (app.exists()) {
      QString appName = cmd.right(cmd.length() - cmd.findRev("/"));
      if (appName.findRev(".app") == (int)(appName.length() - 4)) appName = appName.left(appName.length() - 4);
      qDebug(appName);
      QString cmdBin = cmdApp + "/Contents/MacOS" + appName;
      qDebug(cmdBin);
    
      valArg = "\"" + cmdBin + "\"" + argRight;
   }
   qDebug(valArg);

   return valArg;
}

//----------------------------------------------------------------------------

#endif  //Q_WS_MAC
